#!/bin/bash

ORIG_PWD=$(pwd)
INSTALL_FILES_DIR="owncloud_install_files"
INSTALL_FILES_DIR=$(realpath "$INSTALL_FILES_DIR")

DISKS=$(lsblk -o "NAME" -r -n -p | grep -P "sd.(\d)+")
if [ -z "$DISKS" ]
then
     echo "Non ho trovato nessun disco!"
     exit
fi

firstpartition=$(echo $DISKS | cut -f1 -d" ")

echo "Partizioni trovate:"
echo $DISKS | xargs lsblk -p -o "NAME,SIZE,MOUNTPOINT,LABEL,FSTYPE" 
echo -n "Scegli una partizione (es $firstpartition):"
read DATA_PARTITION

if [ -z $DATA_PARTITION ]
then
    echo "Selezionare una partizione"
    exit
fi

if [ ! -b $DATA_PARTITION ]
then
    echo "$DATA_PARTITION non è una partizione esistente"
    exit
fi

echo "Sicuro di voler usare $DATA_PARTITION come partizione dati di ownCloud?"
echo "Questa partizione verrà montata automaticamente a /var/www/owncloud/data"
echo "ownCloud non funzionerà se il disco o la partizione verranno rimossi/modificati"
echo -n "[s/N] >"
read confirm
if [ "$confirm" != "s" -a "$confirm" != 'S' ]
then
    echo "Fermo l'installazione"
    exit
fi

if [ $(whoami) != "root" ]
then
    echo "Devi invocare questo comando come utente root!"
    echo "Usa sudo $0"
    exit
fi

echo "Preparo il disco di servizio"
DEBIAN_FRONTEND=noninteractive apt-get install -y ntfs-3g

if [ -n "$(cat /proc/mounts | grep "$DATA_PARTITION")" ]
then
    echo "Rimonto $DATA_PARTITION"
    umount $DATA_PARTITION
fi
mkdir -p /var/www/owncloud/data
mount -o rw "$DATA_PARTITION" /var/www/owncloud/data
chown -R www-data:www-data /var/www/owncloud/data

UUID=$(lsblk $DATA_PARTITION -n -o "UUID")

# Rimpiazzo vecchie voci nel file fstab
sed -i "s@^$DATA_PARTITION@#$DATA_PARTITION@" /etc/fstab
sed -i "s@^UUID=$UUID@#UUID=$UUID@" /etc/fstab
echo "UUID=$UUID /var/www/owncloud/data auto nofail,umask=0027,dmask=0027,noatime 0 0" >> /etc/fstab


mkdir -p "$INSTALL_FILES_DIR"
cd "$INSTALL_FILES_DIR"

echo "Installo caddy.."
echo "Scarico.."
wget "https://github.com/mholt/caddy/releases/download/v0.9.3/caddy_linux_arm7.tar.gz"

echo "Estraggo.."
mkdir caddy
cd caddy
tar xzf ../caddy_linux_arm7.tar.gz

echo "Installo.."
# Installo binario
cp caddy_linux_arm7 /usr/local/bin/caddy
chown root:root /usr/local/bin/caddy
chmod 755 /usr/local/bin/caddy
setcap 'cap_net_bind_service=+ep' /usr/local/bin/caddy

# Creo utente/gruppo
groupadd -g 33 www-data
useradd -g www-data --no-user-group --home-dir /var/www --no-create-home --shell /usr/sbin/nologin --system --uid 33 www-data
# Creo home dell'utente
sudo mkdir /var/www
sudo chown www-data:www-data /var/www
sudo chmod 555 /var/www

# Creo dir per config e certificati
mkdir /etc/caddy
chown -R root:www-data /etc/caddy
mkdir /etc/ssl/caddy
chown -R www-data:root /etc/ssl/caddy
chmod 0770 /etc/ssl/caddy

cd "$ORIG_PWD"

# Copio config
cp Caddyfile /etc/caddy/
sudo chown www-data:www-data /etc/caddy/Caddyfile
sudo chmod 444 /etc/caddy/Caddyfile

# Installo servizio di systemd
sudo cp $INSTALL_FILES_DIR/caddy/init/linux-systemd/caddy.service /etc/systemd/system/
sudo chown root:root /etc/systemd/system/caddy.service
sudo chmod 744 /etc/systemd/system/caddy.service

cd "$INSTALL_FILES_DIR"

echo "Installo php"
apt-get update
DEBIAN_FRONTEND=noninteractive apt-get install -y openssl ssl-cert php5-cli php5-sqlite php5-gd php5-common php5-cgi sqlite3 php-pear php-apc curl libapr1 libtool curl libcurl4-openssl-dev php-xml-parser php5 php5-dev php5-curl php5-gd php5-fpm memcached php5-memcache varnish

echo "Configuro php"
# Configuro dimensione massima richieste
sed -i "s/upload_max_filesize/upload_max_filesize = 2000M\n#upload_max_filesize/" /etc/php5/fpm/php.ini
sed -i "s/post_max_size/post_max_size = 2000M\n#post_max_size/" /etc/php5/fpm/php.ini

# Configuro dphys-swapfile
sed -i "s/CONF_SWAPSIZE/CONF_SWAPSIZE=500\n#CONF_SWAPSIZE/" /etc/dphys-swapfile

echo "Installo ownCloud"
wget -nv https://download.owncloud.org/download/repositories/stable/Debian_8.0/Release.key -O Release.key
apt-key add - < Release.key

echo 'deb http://download.owncloud.org/download/repositories/stable/Debian_8.0/ /' > /etc/apt/sources.list.d/owncloud.list
apt-get update
DEBIAN_FRONTEND=noninteractive apt-get install -y owncloud-files

echo "Configuro ownCloud"
sed -i "s/upload_max_filesize.*/upload_max_filesize=2000M/" /var/www/owncloud/.user.ini
sed -i "s/post_max_size.*/post_max_size=2000M/" /var/www/owncloud/.user.ini

echo "Avvio servizi.."
sudo systemctl daemon-reload
sudo systemctl enable caddy
systemctl enable php5-fpm

systemctl start php5-fpm
systemctl start caddy

echo "Fine!"

cd $ORIG_PWD
